ProcessNoCal(Char_t *inputfilename=0, Int_t runno=0, Int_t evnts=1000, Int_t skipevents=0)
{
  Int_t verbose = 0;
  Int_t strit;
  Int_t nstr = 16;
  Int_t fecno[nstr] = { 0,0,0,0,1,1,1,1,8,8,8,8,9,9,9,9 };
  Int_t strno[nstr] = { 0,1,2,3,0,1,2,3,0,1,2,3,0,1,2,3 };

  // INPUT file
  //-----------
  if(!inputfilename) {
     printf("Call run(filename,runno,evnts,skip) with the input file name as a parameter\n");
     return;
  }
  TPhBT98DST *bt = NULL;
  bt = new TPhBT98DST(inputfilename,skipevents,runno);
  bt->SetVerbose(verbose);
  if( !bt->IsInitialized() ) {
     printf("Input file: %s - has not been found\n",inputfilename);
    return;
  }

  // Get TB98 detector
  //------------------
  TPhDetector *det;
  TPhDetector::DeleteInstance();
  const Char_t *phathome = gSystem->Getenv("PHATHOME");
  Char_t *detpath[100];
  sprintf(detpath,"%s/init/Detector_TB98.root",phathome);
  TFile *detfile = new TFile(detpath);
//  TFile *detfile = new TFile("Detector_TB98.root"); 
  det = (TPhDetector *) detfile->Get("TB98_V1.0;1");
  det->Print();

  // Open histograms output
  //-----------------------
  Char_t hisfilname[100];
  Char_t *basename;
  TH1F *his;
  basename = gSystem->BaseName(inputfilename);
  sprintf(hisfilname,"%s_%d_%d.zss_nocal.root",basename,skipevents,evnts);
  TFile *hisf = new TFile(hisfilname,"recreate");

  // Open output with hits
  //-----------------------
  Char_t hitfilname[100];
  Char_t *basename;
  basename = gSystem->BaseName(inputfilename);
  sprintf(hitfilname,"%s_%d_%d.nocal.root",basename,skipevents,evnts);
  TFile *hitf = new TFile(hitfilname,"recreate");

  TPhFECDetector *fecd;
  TPhFEC *fec;
  TPhString *str;

  det->BuildFECDetector();
  fecd = det->GetFECDetector();
  fecd->SetVerboseDown(verbose);
  fecd->SetMIN_NUM_PED_EVENTS(300);
  //  fecd->SetMIPADC(35);
  fecd->SetMIN_CHANNELS_CMN_EST(5);
  fecd->SetMIN_NUM_NOISE_EVENTS(300);
  fecd->SetTHRESH_CMN(3);
  fecd->SetTHRESH_MULTIPLIER(5);

  //  fec = fecd->GetFEC(8);
  //  str = fec->GetString(0);

  fecd->SetDoHistograms(kTRUE);

  // Histogram definitions, canvas preparation
  for(strit=0;strit<nstr;strit++) {
    str = fecd->GetString(fecno[strit],strno[strit]);
    str->AddPedMeanHistogram(-1, 0, 4095, 4095);
    str->AddPedRMSHistogram(-1, 0, 50, 100);
    str->AddNoiseHistogram(-1, 0, 50, 100);
    str->AddZSSHistogram(-1, -20, 100, 240);
    str->AddCalHistogram(-1, -500, 1000, 1200);
  }


  const Int_t kSingleUpdate = 10, kSummaryUpdate = 100;

  TBenchmark bench;      // create a benchmark object
  TPhEvent *ev = NULL;
  Bool_t status=kTRUE;
  Char_t s[5];

//---------------- pedestal preprocessing -------------------------------

  // Pedestal pre-evaluation.
  printf("Pedestal pre-evaluation.\n");

  Int_t i=0;
  do {
    if(ev) delete ev;
    ev = bt->GetNextEvent();
    if(!ev) {
      printf("Pedestal pre-evaluation stopped due to a lack of data\n");
      return;
    }
    det->SetEvent(ev);
    if ( !(i%10) ) printf("Ped-pre for event no %d\n",i);
    status = det->PedPreProcess("RawHitFECn0s");
  } while(!status && (++i)<evnts);
  if(ev) delete ev;
  if(status) {
  } else {
    printf("Pedestal pre-evaluation unsuccessful\n");
    return;
  }

//---------------- pedestal processing ----------------------------------

  // Pedestal levels calculation.
  // ----------------------------
  printf("Pedestal levels calculation.\n");

  i=0;
  do {
    if(ev) delete ev;
    ev = bt->GetNextEvent();
    if(!ev) {
      printf("Pedestal evaluation stopped due to a lack of data\n");
      return;
    }
    det->SetEvent(ev);
    if ( !(i%10) ) printf("Ped for event no %d\n",i);
    status = det->PedProcess("RawHitFECn0s");
  } while(!status && (++i)<evnts);
  if(ev) delete ev;
  if(status) {
  } else {
    printf("Pedestal evaluation unsuccessful\n");
    return;
  }

//---------------- noise processing -------------------------------------

  // CMN and Noise calculation.
  // --------------------------
  printf("CMN and Noise calculation.\n");

  // Histogram definitions, canvas preparation
  Bool_t cmnstatus;
  Bool_t noisestatus;
  Int_t i=0;
  do {
    if(ev) delete ev;
    // get next event from raw data file
    ev = bt->GetNextEvent();
    if(!ev) {
      printf("CMN/Noise evaluation stopped due to a lack of data\n");
      return;
    }
    // Compatibility of detector structures not checked for
    det->SetEvent(ev);
    // Compatibility of structures checked for
    // but not used in case of a Test Beam data
    // since these data ARE incompatible
    if(i==1) 
      det->CompatibilityCheck("RawHitFECn0s"); 
    cmnstatus = kFALSE;
    noisestatus = kFALSE;
    if ( !(i%10) ) printf("CMN for event no %d\n",i);

    // do common mode correction on raw data
    cmnstatus = det->CMNProcess("RawHitFECn0s");
    if(cmnstatus) {
    }
    else 
      printf("CMN evaluation unsuccessful in event %d\n",i);

    if(cmnstatus) {
    if ( !(i%10) )   printf("Noise for event no %d\n",i);
    // process noise for noise initialization
      noisestatus = det->NoiseProcess("RawHitFECn0s");
    }
  } while(!noisestatus && (++i)<evnts);
  if(noisestatus) {
  } else {
    printf("Noise evaluation unsuccessful in event %d\n",i);
    return;
  }

//---------------- calibration parameters -------------------------------

  printf("Readin calibration data base.\n");
  fecd->ReadinStringCalibrationTB98File("calbaseNEW.cal");

//---------------- start zero suppression and event loop ----------------

  // Zero suppression calculation.
  // ----------------------------
  printf("Zero suppression calculation.\n");
  Bool_t zssstatus=kTRUE;
  Bool_t calstatus=kTRUE;
  //  dst->Reset();

  // Histogram definitions, canvas preparation
  for(strit=0;strit<nstr;strit++) {
    str = fecd->GetString(fecno[strit],strno[strit]);
    str->AddZSSHistogram(-1, -20, 100, 240);
    str->AddCalHistogram(-1, -50, 200, 250);
  }
  
  // create Data Container
  TPhAbsDataContainer *hc;
  Int_t i=0;

//---------------- start event loop -------------------------------------

  
  do {
    ev = bt->GetNextEvent();
    if(!ev) {
      printf("Zero suppression stopped due to a lack of data\n");
      return;
    }
    det->SetEvent(ev);

    // List what has been put into the event
    // Zero suppress the event data
    // do common mode correction on raw data
    cmnstatus = det->CMNProcess("RawHitFECn0s");
    zssstatus = det->ZeroSuppress("RawHitFECn0s");

    // start making Phobos hitarrays
    //  zero suppression was successful - start making hits
    if(zssstatus) {
      // contruct hit arrays
      //  det->MakeHitArrays("HitArraysSuppressed");
      // construct hits from hit arrays
      // det->MakeHitsOutOfHitArrays("HitArraysSuppressed","HitsSuppressed");
      // calibrate zero suppressed signals      
      fecd->Calibrate(calstatus);
    
      if(calstatus)  {
        // make calibrated hit arrays out of ZSS signals
	det->MakeHitArrays("HitArraysCalibrated");
       // construct hits from hit arrays
        det->MakeHitsOutOfHitArrays("HitArraysCalibrated","HitsSuppressed");

	// write top DST file
      	// remove unwanted containers, i.e. raw data container after we 
      	// are done with raw data processing before we write the data 
      	// to the DST root file
        cont = (TPhDataObject *) ev->GetObject("RawHitFECn0s");
        ev->RemoveObject(cont);  
        delete cont;

	// List event after zero suppression
        if (!(i%10) ) ev->Print("1");
	// Writeout event to a file
      	hitf->cd();
      	ev->Write();

      } else printf("Calibration failed\n");
    }
     else printf("ZSS failed for event %d...\n",i);

    delete ev;
  } while((++i)<evnts);

  
//--------------- end of event loop ------------------------------------------


// write status histograms
  if(zssstatus && calstatus) {
    for(strit=0;strit<nstr;strit++) {
      str = fecd->GetString(fecno[strit],strno[strit]);
      hisf->cd();
      str->CreatePedMeanSHisto();
      his=str->GetPedMeanSHistogram();
      his.Write(); 
      str->CreatePedRMSSHisto();
      his=str->GetPedRMSSHistogram();
      his.Write(); 
      str->CreateNoiseSHisto();
      his=str->GetNoiseSHistogram();
      his.Write(); 
      his = str->GetZSSHistogram(-1);  
      his.Write();
      his = str->GetCalHistogram(-1);  
      his.Write();
    }
  }
  hitf.Close();
  hisf.Close();
}










